powered by
The function returns a vector of available data sources used by ChemSpider. Some ChemSpider functions allow you to restrict which sources are used to lookup the requested query. Restricting the sources makes these queries faster.
cs_datasources(apikey = NULL, verbose = getOption("verbose"))
character; your API key. If NULL (default), cs_check_key() will look for it in .Renviron or .Rprofile.
cs_check_key()
should a verbose output be printed on the console?
Returns a character vector.
https://developer.rsc.org/docs/compounds-v1-trial/1/overview
# NOT RUN { cs_datasources() # }
Run the code above in your browser using DataLab