Learn R Programming

webchem (version 0.0.3.1)

webchem-deprecated: Deprecated function(s) in the webchem package

Description

These functions are provided for compatibility with older version of the webchem package. They may eventually be completely removed.

Usage

allanwood(...)

Arguments

...
Parameters to be passed to the modern version of the function

Details

rl{ allanwood now a synonym for alanwood }